@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,11 +26,12 @@
 $output = [
 	'header' => $data['title'],
 	'body' => (new CForm())
+		->cleanItems()
 		->addItem([
 			$data['errors'],
 			(new CTabView())->addTab('scriptTab', null,
 				(new CPre(
-					(new CList([bold($data['command']), SPACE, $data['message']]))
+					(new CList([bold($data['command']), NBSP(), $data['message']]))
 				))
 			)
 		])
