@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -179,6 +179,18 @@
 			jQuery('form[name="action.edit"]').submit();
 		});
 
+		$('.js-edit-button').on('click', function() {
+			var operation = $(this).data('operation');
+
+			operation_details.open(this, operation.actionid, operation.eventsource, operation.operationtype,
+				JSON.parse($(['#operations_for_popup', operation.operationtype, operation.operationid].join('_')).val())
+			);
+		});
+
+		$('#evaltype').on('change', () => {
+			processTypeOfCalculation();
+		});
+
 		processTypeOfCalculation();
 	});
 
@@ -939,7 +951,7 @@
 	OperationViewType.prototype.setConfig = function(conf) {
 		const {options, selected} = conf;
 		if (options.length == 1) {
-			const $hidden_input = $('<input />', {type: 'hidden', name: this.$select.attr('name'), value: selected});
+			const $hidden_input = $('<input>', {type: 'hidden', name: this.$select.attr('name'), value: selected});
 			this.$select.replaceWith([options[0].name, $hidden_input]);
 		}
 		else {
